@@ -1,7 +1,7 @@
 package Progress::Any;
 
-our $DATE = '2014-10-14'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2015-01-22'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
@@ -408,6 +408,9 @@ sub update {
             if ($outputs{$task}) {
                 for my $output (@{ $outputs{$task} }) {
                     next unless $self->_should_update_output($output, $now);
+                    if (ref($message) eq 'CODE') {
+                        $message = $message->();
+                    }
                     $output->update(
                         indicator => $indicators{$task},
                         message   => $message,
@@ -560,7 +563,7 @@ Progress::Any - Record progress to any output
 
 =head1 VERSION
 
-This document describes version 0.18 of Progress::Any (from Perl distribution Progress-Any), released on 2014-10-14.
+This document describes version 0.19 of Progress::Any (from Perl distribution Progress-Any), released on 2015-01-22.
 
 =head1 SYNOPSIS
 
@@ -573,7 +576,7 @@ In your module:
      my @urls = @_;
      return unless @urls;
      my $progress = Progress::Any->get_indicator(
-         task => "download", target=>~~@urls);
+         task => "download", pos=>0, target=>~~@urls);
      for my $url (@urls) {
          # download the $url ...
          $progress->update(message => "Downloaded $url");
@@ -608,6 +611,7 @@ Another example, demonstrating multiple indicators and the LogAny output:
  my $pdl = Progress::Any->get_indicator(task => 'download');
  my $pcp = Progress::Any->get_indicator(task => 'copy');
 
+ $pdl->pos(10);
  $pdl->target(10);
  $pdl->update(message => "downloading A");
  $pcp->update(message => "copying A");
@@ -805,10 +809,14 @@ Set the new position. If unspecified, defaults to current position + 1. If pos
 is larger than target, outputs will generally still show 100%. Note that
 fractions are allowed.
 
-=item * message => STR
+=item * message => str|code
 
 Set a message to be displayed when updating indicator.
 
+Aside from a string, you can also pass a coderef here. It can be used to delay
+costly calculation. The message will only be calculated when actually sent to
+output.
+
 =item * level => NUM
 
 EXPERIMENTAL, NOT YET IMPLEMENTED BY MOST OUTPUTS. Setting the importance level
@@ -945,10 +953,6 @@ A literal C<%> sign.
 
 =head1 FAQ
 
-=head2 Why don't you use Moo?
-
-Perhaps. For now I'm trying to be minimal and as dependency-free as possible.
-
 =head1 SEE ALSO
 
 Other progress modules on CPAN: L<Term::ProgressBar>,
@@ -981,7 +985,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
